import os, sys
from bs4 import BeautifulSoup
from urllib.request import urlopen

def bojmaker(problem_number):
    url = 'https://www.acmicpc.net/problem/'
    sol = '''import sys
    
sys.stdin = open('input.txt')'''

    html = urlopen('{}{}'.format(url, problem_number))
    bs_object = BeautifulSoup(html, 'html.parser')

    problem_title = bs_object.find('span', id='problem_title').text
    problem_input = bs_object.find('pre', id='sample-input-1').text
    folder_name = str(problem_number) + '_' + problem_title

    try:
        os.mkdir('{}'.format(folder_name))
    except OSError:
        pass

    input_text = open('./{}/input.txt'.format(folder_name), 'w')
    input_text.write(problem_input)
    input_text.close()
    sol_py = open('./{}/sol1.py'.format(folder_name), 'w')
    sol_py.write(sol)
    sol_py.close()
    print('\nㅡㅡㅡㅡㅡㅡㅡㅡㅡ\n{}\n\nSet up completed\nㅡㅡㅡㅡㅡㅡㅡㅡㅡ'.format(folder_name))


problem_number = int(sys.argv[1])

bojmaker(problem_number)


import setuptools

setuptools.setup(
    name="bojmaker",
    version="0.4",
    license='MIT',
    author="6Soo",
    author_email="kkokko-hero@hanmail.net",
    description="Setting up bothering BOJ problems all at once.",
    long_description=open('README.md', 'r', encoding='utf-8').read(),
    url="https://github.com/6Soo/BOJ_maker_for_python",
    packages=setuptools.find_packages(),
    install_requires=['beautifulsoup4'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
)